@@ -21,7 +21,7 @@
 
 `indexFormat` <-
 function(x) {
-  attr(x, '.indexFORMAT')
+  UseMethod('indexFormat')
 }
 
 `indexFormat<-` <-
@@ -29,6 +29,22 @@ function(x, value) {
   UseMethod('indexFormat<-')
 }
 
+`indexFormat.default` <-
+function(x) {
+  attr(x, '.indexFORMAT')
+}
+
+`indexFormat<-.default` <-
+function(x, value) {
+  attr(x, '.indexFORMAT') <- value
+  x
+}
+
+`indexFormat.xts` <-
+function(x) {
+  attr(x, '.indexFORMAT')
+}
+
 `indexFormat<-.xts` <-
 function(x, value) {
   
