@@ -7,7 +7,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -28,10 +28,12 @@ function(x,...)
 `last.default` <-
 function(x,n=1,keep=FALSE,...)
 {
-  xx <- try.xts(x, error=FALSE)
-  if(is.xts(xx)) {
-    xx <- last.xts(x, n=n, keep=keep, ...)
-    return(reclass(xx))
+  if(is.character(n)) {
+    xx <- try.xts(x, error=FALSE)
+    if(is.xts(xx)) {
+      xx <- last.xts(x, n=n, keep=keep, ...)
+      return(reclass(xx))
+    }
   }
   if(is.null(dim(x))) {
     if(n > 0) {
@@ -45,11 +47,11 @@ function(x,n=1,keep=FALSE,...)
     }
   } else {
     if(n > 0) {
-      xx <- x[(NROW(x)-n+1):NROW(x),]
+      xx <- x[(NROW(x)-n+1):NROW(x),,drop=FALSE]
       if(keep) xx <- structure(xx,keep=x[1:(NROW(x)+(-n)),])
       xx
     } else {
-      xx <- x[1:(NROW(x)+n),]
+      xx <- x[1:(NROW(x)+n),,drop=FALSE]
       if(keep) xx <- structure(xx,keep=x[((NROW(x)-(-n)+1):NROW(x)),])
       xx
     }
@@ -59,12 +61,9 @@ function(x,n=1,keep=FALSE,...)
 `last.xts` <-
 function(x,n=1,keep=FALSE,...)
 {
-  if(length(x)==0)
+  if(length(x) == 0)
     return(x)
   if(is.character(n)) {
-#    if(!inherits(index(x),'POSIXt') && !inherits(index(x),'Date'))
-#      stop(paste('subsetting by date is only possible with objects having',
-#           'time based indexes'))
     # n period set
     np <- strsplit(n," ",fixed=TRUE)[[1]]
     if(length(np) > 2 || length(np) < 1)
@@ -75,7 +74,7 @@ function(x,n=1,keep=FALSE,...)
     rpu <- np[length(np)]
     rpf <- ifelse(length(np) > 1, as.numeric(np[1]), 1)
     if(rpu == sp$unit) {
-      n <- rpf    
+      n <- rpf
     } else {
       # if singular - add an s to make it work
       if(substr(rpu,length(strsplit(rpu,'')[[1]]),length(strsplit(rpu,'')[[1]])) != 's')
@@ -99,12 +98,12 @@ function(x,n=1,keep=FALSE,...)
       }
       if(rpf > 0) {
         n <- ep[length(ep)-rpf]+1
-        xx <- x[n:NROW(x)]
+        xx <- x[n:NROW(x),,drop=FALSE]
         if(keep) xx <- structure(xx,keep=x[1:(ep[length(ep)+(-rpf)])])
         return(xx)
       } else {
         n <- ep[length(ep)+rpf]
-        xx <- x[1:n]
+        xx <- x[1:n,,drop=FALSE]
         if(keep) xx <- structure(xx,keep=x[(ep[length(ep)-(-rpf)]+1):NROW(x)])
         return(xx)
       }
@@ -113,13 +112,13 @@ function(x,n=1,keep=FALSE,...)
   if(length(n) != 1) stop("n must be of length 1")
   if(n > 0) {
     n <- min(n, NROW(x))
-    xx <- x[((NROW(x)-n+1):NROW(x))]
+    xx <- x[(NROW(x)-n+1):NROW(x),,drop=FALSE]
     if(keep) xx <- structure(xx,keep=x[1:(NROW(x)+(-n))])
     xx
   } else {
     if(abs(n) >= NROW(x))
       return(x[0])
-    xx <- x[1:(NROW(x)+n)]
+    xx <- x[1:(NROW(x)+n),,drop=FALSE]
     if(keep) xx <- structure(xx,keep=x[((NROW(x)-(-n)+1):NROW(x))])
     xx
   }
